# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2010-2011 OpenERP s.a. (<http://openerp.com>).
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################
{
    'name': 'Web Shortcuts',
    'version': '1.0',
    'category': 'Tools',
    'description': """
Enable shortcuts feature in the web client.
===========================================

Add a Shortcut icon in the systray in order to access the user's shortcuts (if any).

Add a Shortcut icon besides the views title in order to add/remove a shortcut.
    """,
    'author': 'OpenERP SA',
    'website': 'http://openerp.com',
    'depends': ['base'],
    'data': [],
    'js' : ['static/src/js/web_shortcuts.js'],
    'css' : ['static/src/css/web_shortcuts.css'],
    'qweb' : ['static/src/xml/*.xml'],
    'installable': True,
    'auto_install': False,
}

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:



#! /usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Replacement (unofficial) `setup.py` for the `web_shortcuts` module.
Automatically generated by `openerpdist`. See http://noteed.com/openerpdist/.
"""

import setuptools

setuptools.setup(
    name = "openerp-web-shortcuts",
    version = "7.0.406",
    description = "Web Shortcuts",
    long_description = 
"""

Enable shortcuts feature in the web client.
===========================================

Add a Shortcut icon in the systray in order to access the user's shortcuts (if any).

Add a Shortcut icon besides the views title in order to add/remove a shortcut.
    
""",
    url = "http://openerp.com",
    author = "OpenERP SA",
    author_email = "TODO",
    classifiers = [
        "Development Status :: 5 - Production/Stable",
        "Environment :: Plugins",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Natural Language :: English",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: Implementation :: CPython",
    ],
    license = "AGPL-3",
    package_dir = {
        'openerp.addons.web_shortcuts': ".",
    },
    packages = ["openerp.addons.web_shortcuts"],
    package_data = {
        'openerp.addons.web_shortcuts': ["i18n/*.po*","static/src/xml/web_shortcuts.xml","static/src/js/web_shortcuts.js","static/src/img/icon.png","i18n/hr.po","i18n/da.po","i18n/sl.po","i18n/ru.po","i18n/zh_TW.po","i18n/en_GB.po","i18n/cs.po","i18n/fi.po","i18n/pt_BR.po","i18n/ro.po","i18n/es.po","i18n/mn.po","i18n/it.po","i18n/nl.po","i18n/sv.po","i18n/bs.po","i18n/tr.po","i18n/de.po","i18n/lt.po","i18n/hu.po","i18n/vi.po","i18n/el.po","i18n/gl.po","i18n/mk.po","i18n/fr.po","i18n/zh_CN.po","i18n/pl.po","i18n/th.po","i18n/ar.po","i18n/pt.po","static/src/xml/*.xml","static/src/css/web_shortcuts.css","static/src/js/web_shortcuts.js"],
    },
    install_requires = ["openerp-core"],
    tests_require = ["unittest2"],
)
